@@ -411,7 +411,12 @@ class DatasetsClient:
         self,
         locator: DatasetLocator,
     ) -> "pa.Table":
-        query = SqlQuery(f'SELECT * FROM "{locator.branch_id}"."{locator.rid}"')
+        if locator.end_transaction_rid is None:
+            raise ValueError("read failed. unresolved end transaction rid")
+
+        query = SqlQuery(
+            f'SELECT * FROM "{locator.end_transaction_rid}"."{locator.rid}"'
+        )
         response = self._sql_query_service.execute(
             auth_header=self.ctx.auth_token,
             request=SqlExecuteRequest(
